pub struct Net {
pub tap: Tap,
pub mmds_ns: Option<MmdsNetworkStack>,
/* private fields */
}Expand description
VirtIO network device.
It emulates a network device able to exchange L2 frames between the guest and a host-side tap device.
Fields
tap: TapThe backend for this device: a tap.
mmds_ns: Option<MmdsNetworkStack>The MMDS stack corresponding to this interface. Only if MMDS transport has been associated with it.
Implementations
Sourceimpl Net
impl Net
Sourcepub fn new_with_tap(
id: String,
tap: Tap,
guest_mac: Option<MacAddr>,
rx_rate_limiter: RateLimiter,
tx_rate_limiter: RateLimiter,
) -> Result<Self, NetError>
pub fn new_with_tap( id: String, tap: Tap, guest_mac: Option<MacAddr>, rx_rate_limiter: RateLimiter, tx_rate_limiter: RateLimiter, ) -> Result<Self, NetError>
Create a new virtio network device with the given TAP interface.
Sourcepub fn new(
id: String,
tap_if_name: &str,
guest_mac: Option<MacAddr>,
rx_rate_limiter: RateLimiter,
tx_rate_limiter: RateLimiter,
) -> Result<Self, NetError>
pub fn new( id: String, tap_if_name: &str, guest_mac: Option<MacAddr>, rx_rate_limiter: RateLimiter, tx_rate_limiter: RateLimiter, ) -> Result<Self, NetError>
Create a new virtio network device given the interface name.
Sourcepub fn iface_name(&self) -> String
pub fn iface_name(&self) -> String
Provides the host IFACE name of this net device.
Sourcepub fn mmds_ns(&self) -> Option<&MmdsNetworkStack>
pub fn mmds_ns(&self) -> Option<&MmdsNetworkStack>
Provides the MmdsNetworkStack of this net device.
Sourcepub fn configure_mmds_network_stack(
&mut self,
ipv4_addr: Ipv4Addr,
mmds: Arc<Mutex<Mmds>>,
)
pub fn configure_mmds_network_stack( &mut self, ipv4_addr: Ipv4Addr, mmds: Arc<Mutex<Mmds>>, )
Configures the MmdsNetworkStack to allow device to forward MMDS requests.
If the device already supports MMDS, updates the IPv4 address.
Sourcepub fn disable_mmds_network_stack(&mut self)
pub fn disable_mmds_network_stack(&mut self)
Disables the MmdsNetworkStack to prevent device to forward MMDS requests.
Sourcepub fn rx_rate_limiter(&self) -> &RateLimiter
pub fn rx_rate_limiter(&self) -> &RateLimiter
Provides a reference to the configured RX rate limiter.
Sourcepub fn tx_rate_limiter(&self) -> &RateLimiter
pub fn tx_rate_limiter(&self) -> &RateLimiter
Provides a reference to the configured TX rate limiter.
pub fn rate_limited_rx_single_frame(&mut self, frame_size: u32) -> bool
Sourcepub fn parse_rx_descriptors(&mut self) -> Result<(), InvalidAvailIdx>
pub fn parse_rx_descriptors(&mut self) -> Result<(), InvalidAvailIdx>
Parse available RX DescriptorChains from the queue
Sourcepub fn build_tap_offload_features(guest_supported_features: u64) -> u32
pub fn build_tap_offload_features(guest_supported_features: u64) -> u32
Builds the offload features we will setup on the TAP device based on the features that the guest supports.
Sourcepub fn patch_rate_limiters(
&mut self,
rx_bytes: BucketUpdate,
rx_ops: BucketUpdate,
tx_bytes: BucketUpdate,
tx_ops: BucketUpdate,
)
pub fn patch_rate_limiters( &mut self, rx_bytes: BucketUpdate, rx_ops: BucketUpdate, tx_bytes: BucketUpdate, tx_ops: BucketUpdate, )
Updates the parameters for the rate limiters
Sourcepub unsafe fn read_tap(&mut self) -> Result<usize>
pub unsafe fn read_tap(&mut self) -> Result<usize>
Reads a frame from the TAP device inside the first descriptor held by self.rx_buffer.
Safety
self.rx_buffer needs to have at least one descriptor chain parsed
Sourcepub fn process_rx_queue_event(&mut self)
pub fn process_rx_queue_event(&mut self)
Process a single RX queue event.
This is called by the event manager responding to the guest adding a new buffer in the RX queue.
pub fn process_tap_rx_event(&mut self)
Sourcepub fn process_tx_queue_event(&mut self)
pub fn process_tx_queue_event(&mut self)
Process a single TX queue event.
This is called by the event manager responding to the guest adding a new buffer in the TX queue.
pub fn process_rx_rate_limiter_event(&mut self)
pub fn process_tx_rate_limiter_event(&mut self)
Sourcepub fn process_virtio_queues(&mut self) -> Result<(), InvalidAvailIdx>
pub fn process_virtio_queues(&mut self) -> Result<(), InvalidAvailIdx>
Process device virtio queue(s).
Sourcepub fn prepare_save(&mut self)
pub fn prepare_save(&mut self)
Prepare saving state